# yaconfiglib
Another Config lib for python, basically load config/yaml/toml/... files and add some features like relative import and templating.

# Inspire/Based on v1 of yamlinclude:
Source: https://github.com/tanbro/pyyaml-include 

# Also based on hiyapyco for chain loading/merge template support
Source: https://github.com/zerwes/hiyapyco


